@@ -14,6 +14,12 @@
     DieselType = "Contack_contact_platform",
     db_rename = "Contack_contact_platform"
 )]
+#[cfg_attr(
+    feature = "sqlx",
+    derive(sqlx::Type),
+    sqlx(type_name = "contack_contact_platform"),
+    sqlx(rename_all = "PascalCase")
+)]
 pub enum ContactPlatform {
     Email,
     Tel,
@@ -83,7 +89,7 @@ impl std::fmt::Display for ContactPlatform {
                 Self::Icq => "ICQ",
                 Self::Groupwise => "GroupWise",
                 Self::Gadugadu => "GaduGadu",
-                Self::Unknown => "Unkown",
+                Self::Unknown => "Unknown",
             }
         )
     }
