@@ -1,18 +1,17 @@
 #[cfg(feature = "chrono")]
-use chrono::{Datelike, NaiveDate, NaiveDateTime, NaiveTime, Timelike};
+use chrono::{Datelike, NaiveDate, NaiveDateTime, Timelike};
 
 #[cfg(feature = "rolodex_support")]
 use ::rolodex::value::TypeOrRaw;
 
 use std::convert::TryFrom;
 use std::convert::TryInto;
-use std::error::Error;
 
-#[cfg(feature = "read_write")]
-use crate::read_write::error::FromComponentError;
 #[cfg(feature = "read_write")]
 use crate::read_write::component::Component;
 #[cfg(feature = "read_write")]
+use crate::read_write::error::FromComponentError;
+#[cfg(feature = "read_write")]
 use regex::Regex;
 
 #[cfg_attr(
@@ -57,14 +56,14 @@ pub struct DateTimeError(());
 #[cfg(feature = "chrono")]
 impl From<DateTime> for Option<chrono::NaiveDateTime> {
     fn from(them: DateTime) -> Self {
-        NaiveDate::from_ymd_opt(
-            them.year,
-            them.month.into(),
-            them.day.into(),
-        )
-        .map(|x| {
-            x.and_hms(them.hour.into(), them.minute.into(), them.second.into())
-        })
+        NaiveDate::from_ymd_opt(them.year, them.month.into(), them.day.into())
+            .map(|x| {
+                x.and_hms(
+                    them.hour.into(),
+                    them.minute.into(),
+                    them.second.into(),
+                )
+            })
     }
 }
 
@@ -162,8 +161,7 @@ impl TryFrom<Component> for DateTime {
         }
         // Try to parse, first with the most detailed (RE2)
         let mut capture = RE2.captures(
-            comp
-                .values
+            comp.values
                 .get(0)
                 .ok_or(FromComponentError::NotEnoughValues)?
                 .get(0)
@@ -173,8 +171,7 @@ impl TryFrom<Component> for DateTime {
         // Failing that we will assume its just a date
         if capture.is_none() {
             capture = RE1.captures(
-                comp
-                    .values
+                comp.values
                     .get(0)
                     .ok_or(FromComponentError::NotEnoughValues)?
                     .get(0)
@@ -185,8 +182,7 @@ impl TryFrom<Component> for DateTime {
         // Failing still we will hope it is just a time
         if capture.is_none() {
             capture = RE3.captures(
-                comp
-                    .values
+                comp.values
                     .get(0)
                     .ok_or(FromComponentError::NotEnoughValues)?
                     .get(0)
