@@ -30,10 +30,9 @@ impl fmt::Display for VCard {
 }
 
 impl FromStr for VCard {
-    type Err = Box<dyn std::error::Error>;
+    type Err = super::component::error::ComponentParseError;
 
     fn from_str(s: &str) -> Result<Self, Self::Err> {
-        
         // Unfold all the lines, so that we know what to give the components
         let unfolded = escape::unfold_line(s);
 
