@@ -1,7 +1,7 @@
 #[cfg(feature = "read_write")]
-use crate::read_write::error::FromComponentError;
-#[cfg(feature = "read_write")]
 use crate::read_write::component::Component;
+#[cfg(feature = "read_write")]
+use crate::read_write::error::FromComponentError;
 #[cfg(feature = "sql")]
 use crate::SqlConversionError;
 #[cfg(feature = "read_write")]
@@ -32,7 +32,8 @@ impl Uri {
 #[cfg(feature = "sql")]
 impl Uri {
     /// Converts an Uri into something which can be used by a `SqlContact`
-    #[must_use] pub fn to_sql_raw(
+    #[must_use]
+    pub fn to_sql_raw(
         this: Option<Self>,
     ) -> (Option<String>, Option<Vec<u8>>, Option<String>) {
         match this {
@@ -51,7 +52,7 @@ impl Uri {
     /// for path, when given an error.
     pub fn try_from_sql_raw(
         tup: (Option<String>, Option<Vec<u8>>, Option<String>, String),
-   ) -> Result<Option<Self>, SqlConversionError> {
+    ) -> Result<Option<Self>, SqlConversionError> {
         match tup.0 {
             // Standard URL
             Some(val) => Ok(Some(Self::new_url(val))),
